<a id="v0.1.0"></a>
# [v0.1.0](https://github.com/awslabs/aurora-dsql-django/releases/tag/v0.1.0) - 2024-12-04

## What's Changed

Initial version of the [Aurora DSQL](https://aws.amazon.com/rds/aurora/dsql/) Django adapter.

**Full Changelog**: [link](https://github.com/awslabs/aurora-dsql-django/commits/v0.1.0)

[Changes][v0.1.0]


[v0.1.0]: https://github.com/awslabs/aurora-dsql-django/tree/v0.1.0

<!-- Generated by https://github.com/rhysd/changelog-from-release v3.9.0 -->
